@@ -16,15 +16,19 @@ def main():
     parser.add_argument('--leases', default='/tmp/dhcp.leases', metavar='<leases-file>')
     parser.add_argument('--hosts', default='/etc/hosts', metavar='<hosts-file>')
     parser.add_argument('--ethers', default='/etc/ethers', metavar='<ethers-file>')
-    parser.add_argument('--network', '-n', default='lan', metavar='<interface>')
+    parser.add_argument('--network', '-n', default='lan', metavar='<interface>[,...]',
+                        help='logical network interfaces (e.g. \'lan\') to list')
     parser.add_argument('--wireless', '-w', default='wlan0,wlan1',
-                        metavar='<interface>[@<host>][:<alias>]')
+                        metavar='<interface>[@<host>][:<alias>][,...]',
+                        help='wireless interfaces, see README.md')
     parser.add_argument('--format', '-f', dest='format_str', default=default_format,
                         metavar='"<format string>"')
     parser.add_argument('--sort', '-s', default='ip_as_int', metavar='<sort key>')
     parser.add_argument('--no-ghosts', dest='no_ghosts', action='store_true')
     parser.add_argument('--no-header', dest='no_header', action='store_true')
     parser.add_argument('--identity', '-i', metavar='<identity file>')
+    parser.add_argument('--greppable', '-g', action='store_const', const='-', default = ' ',
+                        help='fixed number of space-separated output fields')
     parser.add_argument('--version', '-v', action='version',
                         version=pkg_resources.require('wrtview')[0].version)
     parser.add_argument('router', nargs='?', metavar='<name or ip>', default='192.168.1.1')
@@ -162,10 +166,10 @@ def main():
     # Fix up missing keys
     for host in hosts:
         # Make sure sort key exists for all hosts
-        host[args.sort] = host.get(args.sort, ' ')
-        # make sure the fields used in format_str are ' ' if they didn't exist
+        host[args.sort] = host.get(args.sort, args.greppable)
+        # make sure the fields used in format_str are ' ' (or '-' if greppable) if they didn't exist
         for field in re.findall('\{(.*?)[\:\}]', args.format_str):
-            host[field] = host.get(field, ' ');
+            host[field] = host.get(field, args.greppable);
         # add numeric ip for sorting
         host['ip_as_int'] = ip2int(host.get('ip', ''))
 
@@ -209,15 +213,14 @@ def get_output(command, router = None):
         shell_command = command
     else:
         identity = ' -i ' + args.identity if args.identity else ''
-        shell_command = 'ssh' + identity + ' root@' + router + ' ' + command
+        shell_command = 'ssh' + identity + ' -o "BatchMode yes" root@' + router + ' ' + command
     try:
         return subprocess.run(shell_command, shell=True, timeout=5, check=True,
                               stdout=subprocess.PIPE, stderr=subprocess.PIPE
                              ).stdout.decode('utf-8').strip()
-    except subprocess.CalledProcessError as e:
-        sys.stderr.write(e.stderr.decode('utf-8') + '\n')
-        # interactive ssh turns off echo so terminal may be in wrong state
-        subprocess.run('reset', shell=True)
+    except Exception as e:
+        if e.stderr:
+            sys.stderr.write(e.stderr.decode('utf-8') + '\n')
         raise e;
 
 def ip2int(ip):
